
Terminoloji
================================================
Proje kapsamında kullanılan terimler aşağıda açıklanmıştır.

Pazaralanı
~~~~~~~~~~~~~
Çevrimiçi satış platformlarında satış yapmak isteyen şirketlerin, çevrimiçi mağazalar açarak
ürünlerini sunduğu ve kolayca büyük bir müşteri havuzuna ulaşabildiği sistemlerdir.

Akinon Commerce Cloud
~~~~~~~~~~~~~~~~~~~~~~~~
Akinon'un bulut çözümlerini içeren ve de müşterilerin ihtiyaçlarına uygun çözümleri
kendierinin de geliştirebildiği modüler bulut ortamıdır.

Omnitron
~~~~~~~~~~~~~~~~~~~~~
Akinon'un ürün envanterinde temel e-ticaret fonksiyonlarını oluşturan ve tüm satış kanalı
operasyonlarını yönetebildiği bir panel sunan üründür.

Channel App
~~~~~~~~~~~~~~~~
Yeni bir pazaralanı entegrasyonu için gereken temel yapıyı bulunduran ve farklı pazaralanları için
farklı ihtiyaçlar olabileceğinden dolayı esnek bir altyapı sunan projedir.

Channel App Template
~~~~~~~~~~~~~~~~~~~~~
Channel App'i bir bağımlılık olarak barındıran ve yeni pazaralanı entegrasyonu için doğrudan
klonlanarak ilerlenebilecek taslak projedir.

Celery
~~~~~~~~~~~~~~~
Asenkron olarak, belirli zamanlarda ve belirli aralıklarda task çalıştırma imkanı sunan , dağıtık kuyruk
yapısı ile taskları sıralı olarak işleyen ve yoğun kaynak gerektiren kuyruklar için de işçi sayısının
ayarlanabildiği teknolojidir.

Flower
~~~~~~~~~~~~
Flower, Celery için önyüz sağlayan bir yönetim aracıdır.
